
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

#############################
Sample usage for nonmonotonic
#############################

.. include:: ../../nltk/test/nonmonotonic.doctest